from setuptools import setup

setup(name='mml',
      version='0.1.0-alpha',
      description='MML Project developer landmark',
      url='https://mml.n1sh.com',
      author='Nishad',
      author_email='nishad@n1sh.com',
      license='MIT',
      packages=['mml'],
      zip_safe=False)
